# cylindra.widgets.subwidgets

## Simulator

Methods are available in the namespace `ui.simulator`.

::: cylindra.widgets.subwidgets.Simulator
    options:
        show_signature_annotations: false
        heading_level: 4
